@@ -30,6 +30,7 @@ import logging
 from typing import Any, Callable, Optional
 
 from gvm.protocols.base import GvmProtocol
+from gvm.utils import to_dotted_types_dict
 
 from gvm.protocols.gmpv208.entities.alerts import (
     AlertCondition,
@@ -199,15 +200,33 @@ class Gmp(
     VersionMixin,
     VulnerabilitiesMixin,
 ):
+    """Python interface for Greenbone Management Protocol
+
+    This class implements the `Greenbone Management Protocol version 21.04`_
+
+    Arguments:
+        connection: Connection to use to talk with the gvmd daemon. See
+            :mod:`gvm.connections` for possible connection types.
+        transform: Optional transform `callable`_ to convert response data.
+            After each request the callable gets passed the plain response data
+            which can be used to check the data and/or conversion into different
+            representations like a xml dom.
+
+            See :mod:`gvm.transforms` for existing transforms.
+
+    .. _Greenbone Management Protocol version 21.04:
+        https://docs.greenbone.net/API/GMP/gmp-21.04.html
+    .. _callable:
+        https://docs.python.org/3/library/functions.html#callable
+    """
+
     def __init__(
         self,
         connection: GvmConnection,
         *,
         transform: Optional[Callable[[str], Any]] = None,
     ):
-        self.types = {}
-        for t in _TYPE_FIELDS:
-            self.types[t.__name__] = t
+        self.types = to_dotted_types_dict(_TYPE_FIELDS)
 
         super().__init__(connection, transform=transform)
 
