@@ -30,6 +30,14 @@ from gvm.xml import create_parser
 logger = logging.getLogger(__name__)
 
 
+class TypesDict(dict):
+    """For dot.notation access to dictionary attributes"""
+
+    __getattr__ = dict.get
+    __setattr__ = dict.__setitem__
+    __delattr__ = dict.__delitem__
+
+
 def deprecation(message: str):
     warnings.warn(message, DeprecationWarning, stacklevel=2)
 
@@ -62,6 +70,14 @@ def check_command_status(xml: str) -> bool:
         return False
 
 
+def to_dotted_types_dict(types: List) -> TypesDict:
+    """Create a dictionary accessible via dot notation"""
+    dic = {}
+    for typ in types:
+        dic[typ.__name__] = typ
+    return TypesDict(dic)
+
+
 def to_bool(value: bool) -> str:
     return "1" if value else "0"
 
